==> haskell-drbg-0.5.5-270-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-drbg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 DRBG
version:              0.5.5
visibility:           public
id:                   DRBG-0.5.5-KU7QeUbX4cZDG5VTR5VGXQ
key:                  DRBG-0.5.5-KU7QeUbX4cZDG5VTR5VGXQ
license:              BSD-3-Clause
maintainer:           Thomas DuBuisson
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
synopsis:
    Deterministic random bit generator (aka RNG, PRNG) based
    HMACs, Hashes, and Ciphers.

description:          Cryptographically secure RNGs
category:             Cryptography
abi:                  fd3507e73851399aacb4f191e08d0310
exposed:              True
exposed-modules:
    Crypto.Random.DRBG Crypto.Random.DRBG.CTR Crypto.Random.DRBG.HMAC
    Crypto.Random.DRBG.Hash Crypto.Random.DRBG.Types

hidden-modules:       Crypto.Random.DRBG.HashDF
import-dirs:          /usr/lib/ghc-9.0.2/site-local/DRBG-0.5.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/DRBG-0.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-drbg
hs-libraries:         HSDRBG-0.5.5-KU7QeUbX4cZDG5VTR5VGXQ
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    cereal-0.5.8.3-KCibhvvTsuv86wVgcPkD6
    cipher-aes128-0.7.0.6-5KbeINSiu63HfbVrxwmbqI
    crypto-api-0.13.3-H2rQjLwJg166An3m7THxYG
    cryptohash-cryptoapi-0.1.4-1RNa2qSgJfYI0ajogJNPPj
    entropy-0.4.1.10-CwQzC5Ky39pHQuKDZJMypk mtl-2.2.2
    parallel-3.2.2.0-D2aleEa2VnPBr164BdKnms
    prettyclass-1.0.0.0-AJqrHIdddTvAkVxD2LfKcX
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR

haddock-interfaces:   /usr/share/doc/haskell-drbg/html/DRBG.haddock
haddock-html:         /usr/share/doc/haskell-drbg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-drbg-0.5.5-286-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-drbg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 DRBG
version:              0.5.5
visibility:           public
id:                   DRBG-0.5.5-IZj9Kg0XFxCAezMf71Cvam
key:                  DRBG-0.5.5-IZj9Kg0XFxCAezMf71Cvam
license:              BSD-3-Clause
maintainer:           Thomas DuBuisson
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
synopsis:
    Deterministic random bit generator (aka RNG, PRNG) based
    HMACs, Hashes, and Ciphers.

description:          Cryptographically secure RNGs
category:             Cryptography
abi:                  f340e6857e97058a57558f399d27cae4
exposed:              True
exposed-modules:
    Crypto.Random.DRBG Crypto.Random.DRBG.CTR Crypto.Random.DRBG.HMAC
    Crypto.Random.DRBG.Hash Crypto.Random.DRBG.Types

hidden-modules:       Crypto.Random.DRBG.HashDF
import-dirs:          /usr/lib/ghc-9.0.2/site-local/DRBG-0.5.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/DRBG-0.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-drbg
hs-libraries:         HSDRBG-0.5.5-IZj9Kg0XFxCAezMf71Cvam
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    cereal-0.5.8.3-KCibhvvTsuv86wVgcPkD6
    cipher-aes128-0.7.0.6-293OA4UWbW1LiO3lrhXQCd
    crypto-api-0.13.3-EHPdhbKdFzpJPwJ37IaBSu
    cryptohash-cryptoapi-0.1.4-465gN4nTXPT6aKY9sejAG8
    entropy-0.4.1.10-CwQzC5Ky39pHQuKDZJMypk mtl-2.2.2
    parallel-3.2.2.0-D2aleEa2VnPBr164BdKnms
    prettyclass-1.0.0.0-AJqrHIdddTvAkVxD2LfKcX
    tagged-0.8.7-8MQxDldL1qw9fJF5LZxnpf

haddock-interfaces:   /usr/share/doc/haskell-drbg/html/DRBG.haddock
haddock-html:         /usr/share/doc/haskell-drbg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
